@@ -64,7 +64,7 @@ struct _TotemGriloPrivate {
 	Totem *totem;
 	GtkWindow *main_window;
 
-	gboolean plugins_loaded;
+	gboolean plugins_activated;
 
 	GrlSource *local_metadata_src;
 	GrlSource *title_parsing_src;
@@ -1249,6 +1249,22 @@ source_added_cb (GrlRegistry *registry,
 	GrlSupportedOps ops;
 	const char *id;
 
+	self = TOTEM_GRILO (user_data);
+	id = grl_source_get_id (source);
+
+	/* Metadata */
+	if (g_str_equal (id, "grl-video-title-parsing"))
+		self->priv->title_parsing_src = source;
+	else if (g_str_equal (id, "grl-local-metadata"))
+		self->priv->local_metadata_src = source;
+	else if (g_str_equal (id, "grl-metadata-store"))
+		self->priv->metadata_store_src = source;
+	else if (g_str_equal (id, "grl-bookmarks"))
+		self->priv->bookmarks_src = source;
+
+	if (self->priv->plugins_activated == FALSE)
+		return;
+
 	if (source_is_blacklisted (source) ||
 	    source_is_forbidden (source) ||
 	    !(grl_source_get_supported_media (source) & GRL_MEDIA_TYPE_VIDEO)) {
@@ -1258,9 +1274,6 @@ source_added_cb (GrlRegistry *registry,
 		return;
 	}
 
-	self = TOTEM_GRILO (user_data);
-	id = grl_source_get_id (source);
-
 	/* The filesystem plugin */
 	if (g_str_equal (id, "grl-filesystem") &&
 	    self->priv->fs_plugin_configured == FALSE) {
@@ -1273,16 +1286,6 @@ source_added_cb (GrlRegistry *registry,
 	else
 		name = grl_source_get_name (source);
 
-	/* Metadata */
-	if (g_str_equal (id, "grl-video-title-parsing"))
-		self->priv->title_parsing_src = source;
-	else if (g_str_equal (id, "grl-local-metadata"))
-		self->priv->local_metadata_src = source;
-	else if (g_str_equal (id, "grl-metadata-store"))
-		self->priv->metadata_store_src = source;
-	else if (g_str_equal (id, "grl-bookmarks"))
-		self->priv->bookmarks_src = source;
-
 	ops = grl_source_supported_operations (source);
 	if (ops & GRL_OP_BROWSE) {
 		gboolean monitor = FALSE;
@@ -1290,8 +1293,7 @@ source_added_cb (GrlRegistry *registry,
 		if (source_is_recent (source)) {
 			browse (self, self->priv->recent_model,
 				NULL, source, NULL, -1);
-			if (g_str_equal (id, "grl-tracker-source") == FALSE)
-				monitor = TRUE;
+			monitor = TRUE;
 		} else if (!source_is_browse_blacklisted (source)) {
 			const GdkPixbuf *icon;
 
@@ -1410,6 +1412,12 @@ load_grilo_plugins (TotemGrilo *self)
 	GSettings *settings;
 	char **configs;
 	guint i;
+	const char *required_plugins[] = {
+		"grl-lua-factory",
+		"grl-local-metadata",
+		"grl-metadata-store",
+		"grl-bookmarks"
+	};
 
 	registry = grl_registry_get_default ();
 
@@ -1433,9 +1441,17 @@ load_grilo_plugins (TotemGrilo *self)
 	g_signal_connect (registry, "source-removed",
 	                  G_CALLBACK (source_removed_cb), self);
 
-	if (grl_registry_load_all_plugins (registry, TRUE, &error) == FALSE) {
+	if (grl_registry_load_all_plugins (registry, FALSE, &error) == FALSE) {
 		g_warning ("Failed to load grilo plugins: %s", error->message);
 		g_error_free (error);
+		return;
+	}
+
+	for (i = 0; i < G_N_ELEMENTS(required_plugins); i++) {
+		if (!grl_registry_activate_plugin_by_id (registry, required_plugins[i], &error)) {
+			g_warning ("Failed to load %s plugin: %s", required_plugins[i], error->message);
+			g_clear_error (&error);
+		}
 	}
 }
 
@@ -2080,6 +2096,7 @@ delete_foreach (gpointer data,
 	GtkTreeIter iter;
 	GrlSource *source;
 	GrlMedia *media;
+	gboolean source_supports_remove;
 	gboolean success;
 	GError *error = NULL;
 
@@ -2098,13 +2115,18 @@ delete_foreach (gpointer data,
 			    MODEL_RESULTS_SOURCE, &source,
 			    -1);
 
+	source_supports_remove = (grl_source_supported_operations (source) & GRL_OP_REMOVE);
 	success = TRUE;
-	if (grl_source_supported_operations (source) & GRL_OP_REMOVE) {
+
+	if (source_supports_remove) {
 		g_debug ("Removing item '%s' through Grilo",
 			 grl_media_get_id (media));
 		grl_source_remove_sync (source, media, &error);
 		success = (error == NULL);
-	} else {
+	}
+
+	if (!source_supports_remove ||
+	    g_strcmp0 (grl_source_get_id (source), "grl-bookmarks") == 0) {
 		const char *uri;
 
 		uri = grl_media_get_url (media);
@@ -2120,6 +2142,7 @@ delete_foreach (gpointer data,
 			g_object_unref (file);
 		}
 	}
+
 	if (!success) {
 		g_warning ("Couldn't remove item '%s' (%s): %s",
 			   grl_media_get_title (media),
@@ -2496,17 +2519,26 @@ totem_grilo_finalize (GObject *object)
 void
 totem_grilo_start (TotemGrilo *self)
 {
+	GError *error = NULL;
+	GrlRegistry *registry;
+
 	g_debug ("TotemGrilo: Resuming videos thumbnailing");
 
 	totem_grilo_resume_icon_thumbnailing ();
 
-	if (self->priv->plugins_loaded)
+	if (self->priv->plugins_activated)
 		return;
 
-	g_debug ("TotemGrilo: Loading plugins");
+	g_debug ("TotemGrilo: Activating plugins");
 
-	load_grilo_plugins (self);
-	self->priv->plugins_loaded = TRUE;
+	registry = grl_registry_get_default ();
+	self->priv->plugins_activated = TRUE;
+
+	/* Load the others */
+	if (grl_registry_load_all_plugins (registry, TRUE, &error) == FALSE) {
+		g_warning ("Failed to activate grilo plugins: %s", error->message);
+		g_error_free (error);
+	}
 }
 
 void
@@ -2526,6 +2558,7 @@ totem_grilo_constructed (GObject *object)
 	setup_ui (self);
 	grl_init (0, NULL);
 	setup_config (self);
+	load_grilo_plugins (self);
 }
 
 gboolean
